from setuptools import setup

setup(name='pizaa', version=0.22, description='Python image to ascii-art library', packages=['pizaa'], author_email='mrtnb1998@gmail.com', zip_safe=False, author='Kollob', install_requires=['pillow'], long_description='file: README.md', long_description_content_type='text/markdown')
